@@ -1,222 +1,270 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="zh_CN">
-<defaultcodec></defaultcodec>
+<!DOCTYPE TS>
+<TS version="2.0" language="zh_CN">
 <context>
     <name>TxtReader</name>
     <message>
-        <location filename="../src/TxtReader.cpp" line="8"/>
-        <source>TXT Reader %1 --- By lsyer</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="651"/>
-        <source>bookmark%1words</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="650"/>
-        <source>bookmark%1index</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="584"/>
+        <location filename="../src/TxtReader.cpp" line="140"/>
+        <location filename="../src/TxtReader.cpp" line="281"/>
+        <location filename="../src/TxtReader.cpp" line="847"/>
         <source>Page %1 /Total %2</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="147"/>
+        <location filename="../src/TxtReader.cpp" line="255"/>
+        <location filename="../src/TxtReader.cpp" line="290"/>
         <source>Cannot read file,please contact to author!</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="200"/>
+        <location filename="../src/TxtReader.cpp" line="569"/>
+        <source>&amp;Changes</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="299"/>
+        <source>TxtReader Changes</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="224"/>
+        <source>Read File Failed</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="225"/>
+        <source>Failed to read file %1.
+Perhaps it is not there, or you don&apos;t have access permission.</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="304"/>
+        <source>&amp;Close</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="366"/>
         <source>&amp;GB2312</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="206"/>
+        <location filename="../src/TxtReader.cpp" line="372"/>
         <source>&amp;UTF-8</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="361"/>
+        <location filename="../src/TxtReader.cpp" line="440"/>
+        <location filename="../src/TxtReader.cpp" line="534"/>
         <source>&amp;%1 %2</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="337"/>
-        <source>%1 - Txt Reader %2</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="380"/>
+        <location filename="../src/TxtReader.cpp" line="553"/>
         <source>Open new file</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="380"/>
+        <location filename="../src/TxtReader.cpp" line="553"/>
         <source>text files (*.txt)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="411"/>
-        <source>Jump to:</source>
-        <translation></translation>
+        <location filename="../src/TxtReader.cpp" line="568"/>
+        <source>&lt;p align=center&gt;Txt Reader %1 &lt;/p&gt;&lt;p align=right&gt; Design by &lt;a href=&apos;HOMEPAGE&apos; target=_blank&gt;lsyer&lt;/a&gt;&lt;/p&gt;&lt;p align=center&gt;CopyLeft(C)2006-YEAR&lt;/p&gt;</source>
+        <translation>&lt;p align=center&gt;Txt Reader %1 &lt;/p&gt;&lt;p align=right&gt; Design by &lt;a href=&apos;http://code.google.com/p/txtreader4linux/&apos; target=_blank&gt;lsyer&lt;/a&gt;&lt;/p&gt;&lt;p align=center&gt;CopyLeft(C)2006-2011&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="421"/>
-        <source>Please input the mark:</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="422"/>
-        <source>%1</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="424"/>
-        <source>%2 - (page %1)</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="473"/>
-        <source>Set Font - TxtReader %1</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="504"/>
-        <source>Select bg-image</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="504"/>
-        <source>picture files (*.png *.jpg *.jpeg *.gif)</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="586"/>
-        <source>&amp;Open</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="587"/>
-        <source>&amp;Jump</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="588"/>
-        <source>&amp;Add Bookmark</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="589"/>
-        <source>&amp;Del Bookmark</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="590"/>
-        <source>&amp;Zoom In</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="591"/>
-        <source>&amp;Zoom Out</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="592"/>
-        <source>&amp;Set Font</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="593"/>
-        <source>&amp;Color</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="594"/>
-        <source>&amp;Bg color</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="595"/>
-        <source>&amp;Bg image</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="596"/>
-        <source>&amp;Reset</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="597"/>
-        <source>&amp;Full Screen</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="598"/>
-        <source>&amp;Exit Fullscreen</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="599"/>
-        <source>&amp;Hide</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="600"/>
-        <source>&amp;Restore</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="601"/>
-        <source>&amp;Quit</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="602"/>
-        <source>&amp;About</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="603"/>
-        <source>&amp;Instruction</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="605"/>
-        <source>&amp;Language</source>
+        <location filename="../src/TxtReader.cpp" line="571"/>
+        <source>&amp;Back</source>
         <translation></translation>
     </message>
     <message>
         <location filename="../src/TxtReader.cpp" line="606"/>
+        <source>Jump to:</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="618"/>
+        <source>Search:</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="645"/>
+        <source>Please input the mark:</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="646"/>
+        <location filename="../src/TxtReader.cpp" line="648"/>
+        <source>%1</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="776"/>
+        <source>Select bg-image</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="776"/>
+        <source>picture files (*.png *.jpg *.jpeg *.gif)</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="849"/>
+        <source>&amp;Open</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="850"/>
+        <source>&amp;Jump</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="851"/>
+        <source>&amp;Add Bookmark</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="854"/>
+        <source>&amp;Find</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="855"/>
+        <source>&amp;Next</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="856"/>
+        <source>&amp;Zoom In</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="857"/>
+        <source>&amp;Zoom Out</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="858"/>
+        <source>&amp;Set Font</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="859"/>
+        <source>&amp;Color</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="860"/>
+        <source>&amp;Bg color</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="861"/>
+        <source>&amp;Bg image</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="862"/>
+        <source>&amp;Reset</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="863"/>
+        <source>&amp;Full Screen</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="864"/>
+        <source>&amp;Exit Fullscreen</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="865"/>
+        <source>&amp;Hide</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="866"/>
+        <source>&amp;Restore</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="867"/>
+        <source>&amp;Quit</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="868"/>
+        <source>&amp;About</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="876"/>
+        <source>&amp;Search</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="283"/>
+        <location filename="../src/TxtReader.cpp" line="869"/>
+        <source>&amp;Instruction</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="563"/>
+        <source>About</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="684"/>
+        <location filename="../src/TxtReader.cpp" line="698"/>
+        <source>txtreader_%1</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="743"/>
+        <source>Set Font - Txt Reader %1</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="852"/>
+        <source>&amp;Del Current</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="853"/>
+        <source>&amp;Clear All</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="871"/>
+        <source>&amp;Language</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../src/TxtReader.cpp" line="872"/>
         <source>&amp;Bookmark</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="607"/>
+        <location filename="../src/TxtReader.cpp" line="873"/>
         <source>&amp;Font</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="608"/>
+        <location filename="../src/TxtReader.cpp" line="874"/>
         <source>&amp;Background</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="609"/>
+        <location filename="../src/TxtReader.cpp" line="875"/>
         <source>&amp;Codec</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../src/TxtReader.cpp" line="135"/>
+        <location filename="../src/TxtReader.cpp" line="273"/>
         <source>&amp;Go Back</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="../src/TxtReader.cpp" line="387"/>
-        <source>&lt;p align=center&gt;Txt Reader %1 &lt;/p&gt;&lt;p align=right&gt; Design by &lt;a href=&apos;http://lishao378.blog.sohu.com&apos; target=_blank&gt;lsyer&lt;/a&gt;&lt;/p&gt;&lt;p align=center&gt;CopyLeft(C)2006-2008&lt;/p&gt;</source>
-        <translation>&lt;p align=center&gt;Txt Reader（文本阅读器） %1 &lt;/p&gt;&lt;p align=right&gt; Design by &lt;a href=&apos;http://lishao378.blog.sohu.com&apos; target=_blank&gt;lsyer&lt;/a&gt;&lt;/p&gt;&lt;p align=center&gt;CopyLeft(C)2006-2008&lt;/p&gt;</translation>
-    </message>
 </context>
 </TS>
